@@ -2,7 +2,7 @@ import pandas as pd
 import seaborn as sns
 import matplotlib.pyplot as plt
 
-def ridgePlot(objs, metric, x_label, table='obs'):
+def ridge_plot(objs, metric, x_label, table='obs'):
     plotdata = pd.concat(
         {name: getattr(obj, table) for name, obj in objs.items()},
         names=["sample"]
